@@ -1,5 +1,5 @@
 
-from srvCommon import servMsgType, wsMsgActionTypes
+from nikki_python.srvCommon import servMsgType, wsMsgActionTypes
 
 
 def pySourceInfoEncoder(pys):
