@@ -1,7 +1,7 @@
 
 
-from sourceInfo import sourceInfo
-from srvCommon import servMsgType
+from nikki_python.sourceInfo import sourceInfo
+from nikki_python.srvCommon import servMsgType
 
 class serviceJoinInfo:
     sessionID =''
